@@ -1,4 +1,6 @@
 use strict;
+#Build  MD5 : OgbxN1gZ/0Hmex8Gt93DSg
+#Build Time : 2025-09-19 18:09:53
 use warnings;
 use XS::Log qw(:all);
 
@@ -39,10 +41,10 @@ setLogOptions("level",10);
 my $user = "Alice";
 my $val  = 42;
 
-printInf("Hello %s, value=%d\n", $user, $val);
-printBug("Hello %s, value=%d\n", $user, $val);
-printBug("Hello %s, value=%d\n", $user, $val);
-printBug("Hello %s, value=%d\n", $user, $val);
+printInf("name = %s, value=%d\n", $user, $val);
+printBug("name = %s, value=%d\n", $user, $val);
+printBug("name = %s, value=%d\n", $user, $val);
+printBug("name = %s, value=%d\n", $user, $val);
 printErr("File not found: %s\n", "/tmp/test.txt");
 
-closeLog();
\ No newline at end of file
+closeLog();
